@@ -51,7 +51,10 @@ def create_update_or_replace(obj, client=None, **kwargs):
     api_instance = find_api_instance(obj, client)
     try:
         res = invoke_api(api_instance, 'create', obj, **kwargs)
-        logging.debug('K8s: %s created -> uid=%s', describe(obj), res.metadata.uid)
+        if isinstance(res, dict):
+            logging.debug('K8s: %s created -> uid=%s', describe(obj), res['metadata']['uid'])
+        else:
+            logging.debug('K8s: %s created -> uid=%s', describe(obj), res.metadata.uid)
     except kubernetes.client.rest.ApiException as e:
         if e.reason != 'Conflict':
             raise
@@ -73,7 +76,10 @@ def create_update_or_replace(obj, client=None, **kwargs):
                 res = invoke_api(api_instance, 'delete', obj, **kwargs)
                 logging.debug('K8s: %s DELETED...', describe(obj))
                 res = invoke_api(api_instance, 'create', obj, **kwargs)
-                logging.debug('K8s: %s CREATED -> uid=%s', describe(obj), res.metadata.uid)
+                if isinstance(res, dict):
+                    logging.debug('K8s: %s CREATED -> uid=%s', describe(obj), res['metadata']['uid'])
+                else:
+                    logging.debug('K8s: %s CREATED -> uid=%s', describe(obj), res.metadata.uid)
             except Exception as ex:
                 message = 'K8s: FAILURE updating %s. Exception: %s' % (describe(obj), ex)
                 logging.error(message)
@@ -86,7 +92,10 @@ def patch_object(obj, client=None, **kwargs):
     api_instance = find_api_instance(obj, client)
     try:
         res = invoke_api(api_instance, 'patch', obj, **kwargs)
-        logging.debug('K8s: %s PATCHED -> uid=%s', describe(obj), res.metadata.uid)
+        if isinstance(res, dict):
+            logging.debug('K8s: %s PATCHED -> uid=%s', describe(obj), res['metadata']['uid'])
+        else:
+            logging.debug('K8s: %s PATCHED -> uid=%s', describe(obj), res.metadata.uid)
         return res
     except kubernetes.client.rest.ApiException as e:
         if e.reason == 'Unprocessable Entity':
@@ -101,7 +110,10 @@ def delete_object(obj, client=None, **kwargs):
     api_instance = find_api_instance(obj, client)
     try:
         res = invoke_api(api_instance, 'delete', obj, **kwargs)
-        logging.debug('K8s: %s DELETED. uid was: %s', describe(obj), res.details and res.details.uid or '?')
+        if isinstance(res, dict):
+            logging.debug('K8s: %s DELETED. uid was: %s', describe(obj), res['details'] and res['details']['uid'] or '?')
+        else:
+            logging.debug('K8s: %s DELETED. uid was: %s', describe(obj), res.details and res.details.uid or '?')
         return True
     except kubernetes.client.rest.ApiException as e:
         if e.reason == 'Not Found':
